@@ -350,7 +350,7 @@ LinphoneCall * linphone_call_new_incoming(LinphoneCore *lc, LinphoneAddress *fro
 		 we get a chance to discover our nat'd address before answering.*/
 		call->ping_op=sal_op_new(lc->sal);
 		from_str=linphone_address_as_string_uri_only(from);
-		sal_op_set_route(call->ping_op,sal_op_get_network_origin(call->op));
+		sal_op_set_route(call->ping_op,sal_op_get_network_origin(op));
 		sal_op_set_user_pointer(call->ping_op,call);
 		sal_ping(call->ping_op,linphone_core_find_best_identity(lc,from,NULL),from_str);
 		ms_free(from_str);
