@@ -202,6 +202,7 @@ enum _LinphoneReason{
 	LinphoneReasonNoResponse, /**<No response received from remote*/
 	LinphoneReasonBadCredentials, /**<Authentication failed due to bad or missing credentials*/
 	LinphoneReasonDeclined, /**<The call has been declined*/
+	LinphoneReasonNotFound,
 };
 
 typedef enum _LinphoneReason LinphoneReason;
@@ -344,16 +345,6 @@ typedef enum _LinphoneRegistrationState{
  */
 const char *linphone_registration_state_to_string(LinphoneRegistrationState cs);
 
-/**
- * True if tunnel support was compiled.
- */
-bool_t linphone_core_tunnel_available();
-
-/**
- * Update tunnel using configuration.
- */
-void linphone_core_update_tunnel(LinphoneCore *lc);
-
 LinphoneProxyConfig *linphone_proxy_config_new(void);
 int linphone_proxy_config_set_server_addr(LinphoneProxyConfig *obj, const char *server_addr);
 int linphone_proxy_config_set_identity(LinphoneProxyConfig *obj, const char *identity);
@@ -426,6 +417,9 @@ typedef struct _LinphoneAccountCreator{
 	char *username;
 	char *password;
 	char *domain;
+	char *route;
+	char *email;
+	int suscribe;
 	bool_t succeeded;
 }LinphoneAccountCreator;
 
@@ -433,9 +427,13 @@ LinphoneAccountCreator *linphone_account_creator_new(struct _LinphoneCore *core,
 void linphone_account_creator_set_username(LinphoneAccountCreator *obj, const char *username);
 void linphone_account_creator_set_password(LinphoneAccountCreator *obj, const char *password);
 void linphone_account_creator_set_domain(LinphoneAccountCreator *obj, const char *domain);
+void linphone_account_creator_set_route(LinphoneAccountCreator *obj, const char *route);
+void linphone_account_creator_set_email(LinphoneAccountCreator *obj, const char *email);
+void linphone_account_creator_set_suscribe(LinphoneAccountCreator *obj, int suscribre);
 const char * linphone_account_creator_get_username(LinphoneAccountCreator *obj);
 const char * linphone_account_creator_get_domain(LinphoneAccountCreator *obj);
 int linphone_account_creator_test_existence(LinphoneAccountCreator *obj);
+int linphone_account_creator_test_validation(LinphoneAccountCreator *obj);
 LinphoneProxyConfig * linphone_account_creator_validate(LinphoneAccountCreator *obj);
 void linphone_account_creator_destroy(LinphoneAccountCreator *obj);
 
@@ -961,6 +959,9 @@ void linphone_core_use_preview_window(LinphoneCore *lc, bool_t yesno);
 int linphone_core_get_device_rotation(LinphoneCore *lc );
 void linphone_core_set_device_rotation(LinphoneCore *lc, int rotation);
 
+/* start or stop streaming video in case of embedded window */
+void linphone_core_show_video(LinphoneCore *lc, bool_t show);
+
 /*play/record support: use files instead of soundcard*/
 void linphone_core_use_files(LinphoneCore *lc, bool_t yesno);
 void linphone_core_set_play_file(LinphoneCore *lc, const char *file);
@@ -1084,6 +1085,17 @@ void linphone_core_set_media_encryption_mandatory(LinphoneCore *lc, bool_t m);
  */
 void linphone_core_init_default_params(LinphoneCore*lc, LinphoneCallParams *params);
 
+/**
+ * True if tunnel support was compiled.
+ */
+bool_t linphone_core_tunnel_available(void);
+
+typedef struct LinphoneTunnel LinphoneTunnel;
+/**
+* get tunnel instance if available
+*/
+LinphoneTunnel *linphone_core_get_tunnel(LinphoneCore *lc);
+
 #ifdef __cplusplus
 }
 #endif
