@@ -172,16 +172,20 @@ int linphone_proxy_config_set_route(LinphoneProxyConfig *obj, const char *route)
 		obj->reg_route=NULL;
 	}
 	if (route!=NULL){
-		LinphoneAddress *addr;
+		SalAddress *addr;
+		char *tmp;
 		/*try to prepend 'sip:' */
 		if (strstr(route,"sip:")==NULL){
-			obj->reg_route=ms_strdup_printf("sip:%s",route);
-		}else obj->reg_route=ms_strdup(route);
-		addr=linphone_address_new(obj->reg_route);
-		if (addr==NULL){
-			ms_free(obj->reg_route);
-			obj->reg_route=NULL;
-		}else linphone_address_destroy(addr);
+			tmp=ms_strdup_printf("sip:%s",route);
+		}else tmp=ms_strdup(route);
+		addr=sal_address_new(tmp);
+		if (addr!=NULL){
+			sal_address_destroy(addr);
+		}else{
+			ms_free(tmp);
+			tmp=NULL;
+		}
+		obj->reg_route=tmp;
 	}
 	return 0;
 }
@@ -516,11 +520,9 @@ struct _LinphoneCore * linphone_proxy_config_get_core(const LinphoneProxyConfig
 **/
 int linphone_core_add_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *cfg){
 	if (!linphone_proxy_config_check(lc,cfg)) {
-		linphone_proxy_config_destroy(cfg);
 		return -1;
 	}
 	if (ms_list_find(lc->sip_conf.proxies,cfg)!=NULL){
-		linphone_proxy_config_destroy(cfg);
 		ms_warning("ProxyConfig already entered, ignored.");
 		return 0;
 	}
@@ -536,6 +538,11 @@ int linphone_core_add_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *cfg){
  * on a deleted list. For that reason, a removed proxy does NOT need to be freed.
 **/
 void linphone_core_remove_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *cfg){
+	/* check this proxy config is in the list before doing more*/
+	if (ms_list_find(lc->sip_conf.proxies,cfg)==NULL){
+		ms_error("linphone_core_remove_proxy_config: LinphoneProxyConfig %p is not known by LinphoneCore (programming error?)",cfg);
+		return;
+	}
 	lc->sip_conf.proxies=ms_list_remove(lc->sip_conf.proxies,(void *)cfg);
 	/* add to the list of destroyed proxies, so that the possible unREGISTER request can succeed authentication */
 	lc->sip_conf.deleted_proxies=ms_list_append(lc->sip_conf.deleted_proxies,(void *)cfg);
