@@ -39,13 +39,14 @@ struct Sal{
 	int running;
 	int session_expires;
 	int keepalive_period;
-	void *up;
+	void *up; /*user pointer*/
+	char* rootCa; /* File _or_ folder containing root CA */
 	bool_t one_matching_codec;
 	bool_t double_reg;
 	bool_t use_rports;
 	bool_t use_101;
 	bool_t reuse_authorization;
-	char* rootCa; /* File _or_ folder containing root CA */
+	bool_t verify_server_certs;
 };
 
 struct SalOp{
