@@ -44,8 +44,8 @@ void linphone_gtk_call_log_update(GtkWidget *w){
 		gtk_tree_view_set_model(v,GTK_TREE_MODEL(store));
 		g_object_unref(G_OBJECT(store));
 		fill_renderers(GTK_TREE_VIEW(linphone_gtk_get_widget(w,"logs_view")));
-		gtk_button_set_image(GTK_BUTTON(linphone_gtk_get_widget(w,"call_back_button")),
-		                     create_pixmap (linphone_gtk_get_ui_config("callback_button","status-green.png")));
+//		gtk_button_set_image(GTK_BUTTON(linphone_gtk_get_widget(w,"call_back_button")),
+//		                     create_pixmap (linphone_gtk_get_ui_config("callback_button","status-green.png")));
 	}
 	gtk_list_store_clear (store);
 
@@ -55,7 +55,7 @@ void linphone_gtk_call_log_update(GtkWidget *w){
 		LinphoneAddress *la=cl->dir==LinphoneCallIncoming ? cl->from : cl->to;
 		char *addr= linphone_address_as_string_uri_only (la);
 		const char *display;
-		gchar *logtxt;
+		gchar *logtxt, *minutes, *seconds;
 		gchar quality[20];
 		
 		display=linphone_address_get_display_name (la);
@@ -67,10 +67,19 @@ void linphone_gtk_call_log_update(GtkWidget *w){
 		if (cl->quality!=-1){
 			snprintf(quality,sizeof(quality),"%.1f",cl->quality);
 		}
-		logtxt=g_markup_printf_escaped("<big><b>%s</b></big>\t<small><i>%s</i>\t<i>Quality: %s</i></small>\n"
-		                               "%s\t%i minutes %i seconds\t",display, addr, cl->quality!=-1 ? quality : _("n/a"),
-		                               cl->start_date,
-		                               cl->duration/60,cl->duration%60);
+		minutes=g_markup_printf_escaped(
+			ngettext("%i minute", "%i minutes", cl->duration/60),
+			cl->duration/60);
+		seconds=g_markup_printf_escaped(
+			ngettext("%i second", "%i seconds", cl->duration%60),
+			cl->duration%60);
+		logtxt=g_markup_printf_escaped(
+				_("<big><b>%s</b></big>\t<small><i>%s</i>\t"
+					"<i>Quality: %s</i></small>\n%s\t%s %s\t"),
+				display, addr, cl->quality!=-1 ? quality : _("n/a"),
+				cl->start_date, minutes, seconds);
+		g_free(minutes);
+		g_free(seconds);
 		gtk_list_store_append (store,&iter);
 		gtk_list_store_set (store,&iter,
 		               0, cl->dir==LinphoneCallOutgoing ? GTK_STOCK_GO_UP : GTK_STOCK_GO_DOWN,
@@ -110,6 +119,10 @@ void linphone_gtk_history_row_activated(GtkWidget *treeview){
 	}
 }
 
+void linphone_gtk_history_row_selected(GtkWidget *treeview){
+	put_selection_to_uribar(treeview);
+}
+
 void linphone_gtk_clear_call_logs(GtkWidget *button){
 	linphone_core_clear_call_logs (linphone_gtk_get_core());
 	linphone_gtk_call_log_update(gtk_widget_get_toplevel(button));
@@ -143,8 +156,8 @@ GtkWidget * linphone_gtk_show_call_logs(void){
 	GtkWidget *w=(GtkWidget*)g_object_get_data(G_OBJECT(linphone_gtk_get_main_window()),"call_logs");
 	if (w==NULL){
 		w=linphone_gtk_create_window("call_logs");
-		gtk_button_set_image(GTK_BUTTON(linphone_gtk_get_widget(w,"call_back_button")),
-		                     create_pixmap (linphone_gtk_get_ui_config("callback_button","status-green.png")));
+//		gtk_button_set_image(GTK_BUTTON(linphone_gtk_get_widget(w,"call_back_button")),
+//		                     create_pixmap (linphone_gtk_get_ui_config("callback_button","status-green.png")));
 		g_object_set_data(G_OBJECT(mw),"call_logs",w);
 		g_signal_connect(G_OBJECT(w),"response",(GCallback)linphone_gtk_call_log_response,NULL);
 		gtk_widget_show(w);
