@@ -1265,7 +1265,7 @@ static void linphone_gtk_status_icon_set_blinking(gboolean val){
 void linphone_gtk_options_activate(GtkWidget *item){
 #ifndef HAVE_GTK_OSX
 	gtk_widget_set_visible(linphone_gtk_get_widget(linphone_gtk_get_main_window(),"quit_item"),
-		icon && !gtk_status_icon_is_embedded(icon));
+		TRUE);
 #endif
 }
 
@@ -1436,7 +1436,13 @@ static void linphone_gtk_configure_main_window(){
 	{
 		GdkPixbuf *pbuf=create_pixbuf("dialer-orange.png");
 		if (pbuf) {
-			gtk_image_set_from_pixbuf(GTK_IMAGE(linphone_gtk_get_widget(w,"keypad_tab_icon")),pbuf);
+			GtkImage *img=GTK_IMAGE(linphone_gtk_get_widget(w,"keypad_tab_icon"));
+			int w,h;
+			GdkPixbuf *scaled;
+			gtk_icon_size_lookup(GTK_ICON_SIZE_MENU,&w,&h);
+			scaled=gdk_pixbuf_scale_simple(pbuf,w,h,GDK_INTERP_BILINEAR);
+			gtk_image_set_from_pixbuf(img,scaled);
+			g_object_unref(G_OBJECT(scaled));
 			g_object_unref(G_OBJECT(pbuf));
 		}
 	}
@@ -1586,12 +1592,14 @@ static void linphone_gtk_check_soundcards(){
 	}
 }
 
+#ifdef BUILD_WIZARD
 // Display the account wizard
 void linphone_gtk_display_wizard() {
 	if (the_wizard == NULL || !gtk_widget_get_visible(the_wizard)) { // Only one instance of the wizard at the same time
 		the_wizard = linphone_gtk_create_assistant();
 	}
 }
+#endif
 
 static void linphone_gtk_quit(void){
 	static gboolean quit_done=FALSE;
@@ -1737,10 +1745,12 @@ int main(int argc, char *argv[]){
 	gtk_timeout_add(30,(GtkFunction)linphone_gtk_check_logs,(gpointer)NULL);
 	linphone_gtk_init_main_window();
 
+#ifdef BUILD_WIZARD
 	// Veryfing if at least one sip account is configured. If not, show wizard
 	if (linphone_core_get_proxy_config_list(linphone_gtk_get_core()) == NULL) {
 		linphone_gtk_display_wizard();
 	}
+#endif
 
 #ifndef HAVE_GTK_OSX
 	linphone_gtk_init_status_icon();
