@@ -131,7 +131,8 @@ typedef enum MSFilterId{
 	MS_AAL2_G726_24_DEC_ID,
 	MS_AAL2_G726_16_DEC_ID,
 	MS_L16_ENC_ID,
-	MS_L16_DEC_ID
+	MS_L16_DEC_ID,
+	MS_OSX_GL_DISPLAY_ID
 } MSFilterId;
 
 
