@@ -21,6 +21,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <ortp/ortp.h>
 #include <time.h>
+#if defined(__APPLE__) 
+#include "TargetConditionals.h"
+#endif
 
 #define ms_malloc	ortp_malloc
 #define ms_malloc0	ortp_malloc0
@@ -216,6 +219,13 @@ MS2_PUBLIC int ms_discover_mtu(const char *destination_host);
 **/
 MS2_PUBLIC void ms_set_mtu(int mtu);
 
+/**
+ * Declare how many cpu (cores) are available on the platform
+ */
+MS2_PUBLIC void ms_set_cpu_count(unsigned int c);
+ 
+MS2_PUBLIC unsigned int ms_get_cpu_count();
+
 /** @} */
 
 #ifdef __cplusplus
