@@ -19,9 +19,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef MSQUEUE_H
 #define MSQUEUE_H
 
-#include "ortp/str_utils.h"
+#include <ortp/str_utils.h>
+#include <mediastreamer2/mscommon.h>
 
-/* for the moment these are stupid queues limited to one element*/
 
 typedef struct _MSCPoint{
 	struct _MSFilter *filter;
@@ -64,24 +64,28 @@ extern "C"
 {
 #endif
 
+/*yes these functions need to be public for plugins to work*/
+
 /*init a queue on stack*/
-void ms_queue_init(MSQueue *q);
+MS2_PUBLIC void ms_queue_init(MSQueue *q);
 
-void ms_queue_flush(MSQueue *q);
+MS2_PUBLIC void ms_queue_flush(MSQueue *q);
 
-void ms_queue_destroy(MSQueue *q);
+MS2_PUBLIC void ms_queue_destroy(MSQueue *q);
 
+
+#define __mblk_set_flag(m,pos,bitval) \
+	(m)->reserved2=(m->reserved2 & ~(1<<pos)) | ((!!bitval)<<pos) 
+	
 #define mblk_set_timestamp_info(m,ts) (m)->reserved1=(ts);
 #define mblk_get_timestamp_info(m)    ((m)->reserved1)
-#define mblk_set_marker_info(m,bit)   (m)->reserved2=((m)->reserved2|bit)
-#define mblk_get_marker_info(m)	      ((m)->reserved2&0x1)
-#define mblk_set_rate(m,bits)         (m)->reserved2=((m)->reserved2|(bits)<<1)
-#define mblk_get_rate(m)              (((m)->reserved2>>1)&0x3)
-#define mblk_set_payload_type(m,bits) (m)->reserved2=((m)->reserved2|(bits<<3))
-#define mblk_get_payload_type(m)      (((m)->reserved2>>3)&0x7F)
-#define mblk_set_precious_flag(m,bit)    (m)->reserved2=(m)->reserved2|((bit & 0x1)<<10) /*use to prevent mirroring*/
-#define mblk_get_precious_flag(m)    (((m)->reserved2)>>10 & 0x1)
-
+#define mblk_set_marker_info(m,bit)   __mblk_set_flag(m,0,bit)
+#define mblk_get_marker_info(m)	      ((m)->reserved2&0x1) /*bit 1*/
+#define mblk_set_precious_flag(m,bit)    __mblk_set_flag(m,1,bit)  /*use to prevent mirroring*/
+#define mblk_get_precious_flag(m)    (((m)->reserved2)>>1 & 0x1) /*bit 2*/
+#define mblk_set_cseq(m,value) (m)->reserved2=(m)->reserved2| ((value&0xFFFF)<<16);	
+#define mblk_get_cseq(m) ((m)->reserved2>>16)
+	
 struct _MSBufferizer{
 	queue_t q;
 	int size;
@@ -90,31 +94,31 @@ struct _MSBufferizer{
 typedef struct _MSBufferizer MSBufferizer;
 
 /*allocates and initialize */
-MSBufferizer * ms_bufferizer_new(void);
+MS2_PUBLIC MSBufferizer * ms_bufferizer_new(void);
 
 /*initialize in memory */
 void ms_bufferizer_init(MSBufferizer *obj);
 
-void ms_bufferizer_put(MSBufferizer *obj, mblk_t *m);
+MS2_PUBLIC void ms_bufferizer_put(MSBufferizer *obj, mblk_t *m);
 
 /* put every mblk_t from q, into the bufferizer */
-void ms_bufferizer_put_from_queue(MSBufferizer *obj, MSQueue *q);
+MS2_PUBLIC void ms_bufferizer_put_from_queue(MSBufferizer *obj, MSQueue *q);
 
-int ms_bufferizer_read(MSBufferizer *obj, uint8_t *data, int datalen);
+MS2_PUBLIC int ms_bufferizer_read(MSBufferizer *obj, uint8_t *data, int datalen);
 
 /* returns the number of bytes available in the bufferizer*/
 static inline int ms_bufferizer_get_avail(MSBufferizer *obj){
 	return obj->size;
 }
 
-void ms_bufferizer_skip_bytes(MSBufferizer *obj, int bytes);
+MS2_PUBLIC void ms_bufferizer_skip_bytes(MSBufferizer *obj, int bytes);
 
 /* purge all data pending in the bufferizer */
-void ms_bufferizer_flush(MSBufferizer *obj);
+MS2_PUBLIC void ms_bufferizer_flush(MSBufferizer *obj);
 
 void ms_bufferizer_uninit(MSBufferizer *obj);
 
-void ms_bufferizer_destroy(MSBufferizer *obj);
+MS2_PUBLIC void ms_bufferizer_destroy(MSBufferizer *obj);
 
 #ifdef __cplusplus
 }
