@@ -21,9 +21,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef MS_TICKER_H
 #define MS_TICKER_H
 
-
-#include "msfilter.h"
-#include "mscommon.h"
+#include <mediastreamer2/msfilter.h>
 
 /**
  * @file msticker.h
@@ -47,6 +45,17 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 typedef uint64_t (*MSTickerTimeFunc)(void *);
 
+/**
+ * Enum for ticker priority
+**/
+enum _MSTickerPrio{
+	MS_TICKER_PRIO_NORMAL, /**<the default OS priority for threads*/
+	MS_TICKER_PRIO_HIGH, /**<Increased priority: done by setpriority() or sched_setschedparams() with SCHED_RR on linux/MacOS*/
+	MS_TICKER_PRIO_REALTIME /**<Topmost priority, running SCHED_FIFO on linux */
+};
+
+typedef enum _MSTickerPrio MSTickerPrio;
+
 struct _MSTicker
 {
 	ms_mutex_t lock;
@@ -61,10 +70,9 @@ struct _MSTicker
 	MSTickerTimeFunc get_cur_time_ptr;
 	void *get_cur_time_data;
 	char *name;
+	double av_load;	/*average load of the ticker */
+	MSTickerPrio prio;
 	bool_t run;       /* flag to indicate whether the ticker must be run or not */
-#ifdef WIN32_TIMERS
-	HANDLE TimeEvent;
-#endif
 };
 
 /**
@@ -85,13 +93,18 @@ extern "C"{
  *
  * Returns: MSTicker * if successfull, NULL otherwise.
  */
-MSTicker *ms_ticker_new(void);
+MS2_PUBLIC MSTicker *ms_ticker_new(void);
 
 /**
  * Set a name to the ticker (used for logging)
 **/
-void ms_ticker_set_name(MSTicker *ticker, const char *name);
+MS2_PUBLIC void ms_ticker_set_name(MSTicker *ticker, const char *name);
 
+/**
+ * Set priority to the ticker
+**/
+MS2_PUBLIC void ms_ticker_set_priority(MSTicker *ticker, MSTickerPrio prio);
+	
 /**
  * Attach a chain of filters to a ticker.
  * The processing chain will be executed until ms_ticker_detach
@@ -102,7 +115,7 @@ void ms_ticker_set_name(MSTicker *ticker, const char *name);
  *
  * Returns: 0 if successfull, -1 otherwise.
  */
-int ms_ticker_attach(MSTicker *ticker,MSFilter *f);
+MS2_PUBLIC int ms_ticker_attach(MSTicker *ticker,MSFilter *f);
 
 /**
  * Dettach a chain of filters to a ticker.
@@ -114,7 +127,7 @@ int ms_ticker_attach(MSTicker *ticker,MSFilter *f);
  *
  * Returns: 0 if successfull, -1 otherwise.
  */
-int ms_ticker_detach(MSTicker *ticker,MSFilter *f);
+MS2_PUBLIC int ms_ticker_detach(MSTicker *ticker,MSFilter *f);
 
 /**
  * Destroy a ticker.
@@ -122,7 +135,7 @@ int ms_ticker_detach(MSTicker *ticker,MSFilter *f);
  * @param ticker  A #MSTicker object.
  *
  */
-void ms_ticker_destroy(MSTicker *ticker);
+MS2_PUBLIC void ms_ticker_destroy(MSTicker *ticker);
 
 /**
  * Override MSTicker's time function.
@@ -133,15 +146,24 @@ void ms_ticker_destroy(MSTicker *ticker);
  * @param func    A replacement method for calculating "current time"
  * @param user_data Any pointer to user private data.
  */
-void ms_ticker_set_time_func(MSTicker *ticker, MSTickerTimeFunc func, void *user_data);
+MS2_PUBLIC void ms_ticker_set_time_func(MSTicker *ticker, MSTickerTimeFunc func, void *user_data);
 
 /**
  * Print on stdout all filters of a ticker. (INTERNAL: DO NOT USE)
  *
  * @param ticker  A #MSTicker object.
  */
-void ms_ticker_print_graphs(MSTicker *ticker);
+MS2_PUBLIC void ms_ticker_print_graphs(MSTicker *ticker);
 
+/**
+ * Get the average load of the ticker.
+ * It is expressed as the ratio between real time spent in processing all graphs for a tick divided by the
+ * tick interval (default is 10 ms).
+ * This value is averaged over several ticks to get consistent and useful value.
+ * A load greater than 100% clearly means that the ticker is over loaded and runs late.
+**/
+MS2_PUBLIC float ms_ticker_get_average_load(MSTicker *ticker);
+	
 /* private functions:*/
 
 #ifdef __cplusplus
