@@ -28,9 +28,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "ortp/b64.h"
 
 
-static uint64_t fpu_last_requested_time=0;
-
-
 typedef struct _DecData{
 	mblk_t *yuv_msg;
 	mblk_t *sps,*pps;
@@ -41,6 +38,7 @@ typedef struct _DecData{
 	unsigned int packet_num;
 	uint8_t *bitstream;
 	int bitstream_size;
+	uint64_t last_error_reported_time;
 }DecData;
 
 static void ffmpeg_init(){
@@ -78,6 +76,7 @@ static void dec_init(MSFilter *f){
 	d->outbuf.h=0;
 	d->bitstream_size=65536;
 	d->bitstream=ms_malloc0(d->bitstream_size);
+	d->last_error_reported_time=0;
 	f->data=d;
 }
 
@@ -190,32 +189,40 @@ static int nalusToFrame(DecData *d, MSQueue *naluq, bool_t *new_sps_pps){
 			dst=d->bitstream+pos;
 			end=d->bitstream+d->bitstream_size;
 		}
-		nalu_type=(*src) & ((1<<5)-1);
-		if (nalu_type==7)
-			*new_sps_pps=check_sps_change(d,im) || *new_sps_pps;
-		if (nalu_type==8)
-			*new_sps_pps=check_pps_change(d,im) || *new_sps_pps;
-		if (start_picture || nalu_type==7/*SPS*/ || nalu_type==8/*PPS*/ ){
+		if (src[0]==0 && src[1]==0 && src[2]==0 && src[3]==1){
+			int size=im->b_wptr-src;
+			/*workaround for stupid RTP H264 sender that includes nal markers */
+			memcpy(dst,src,size);
+			dst+=size;
+		}else{
+			nalu_type=(*src) & ((1<<5)-1);
+			if (nalu_type==7)
+				*new_sps_pps=check_sps_change(d,im) || *new_sps_pps;
+			if (nalu_type==8)
+				*new_sps_pps=check_pps_change(d,im) || *new_sps_pps;
+			if (start_picture || nalu_type==7/*SPS*/ || nalu_type==8/*PPS*/ ){
+				*dst++=0;
+				start_picture=FALSE;
+			}
+		
+			/*prepend nal marker*/
 			*dst++=0;
-			start_picture=FALSE;
-		}
-		/*prepend nal marker*/
-		*dst++=0;
-		*dst++=0;
-		*dst++=1;
-		*dst++=*src++;
-		while(src<(im->b_wptr-3)){
-			if (src[0]==0 && src[1]==0 && src[2]<3){
-				*dst++=0;
-				*dst++=0;
-				*dst++=3;
-				src+=2;
+			*dst++=0;
+			*dst++=1;
+			*dst++=*src++;
+			while(src<(im->b_wptr-3)){
+				if (src[0]==0 && src[1]==0 && src[2]<3){
+					*dst++=0;
+					*dst++=0;
+					*dst++=3;
+					src+=2;
+				}
+				*dst++=*src++;
 			}
 			*dst++=*src++;
+			*dst++=*src++;
+			*dst++=*src++;
 		}
-		*dst++=*src++;
-		*dst++=*src++;
-		*dst++=*src++;
 		freemsg(im);
 	}
 	return dst-d->bitstream;
@@ -259,8 +266,8 @@ static void dec_process(MSFilter *f){
 				len=avcodec_decode_video2(&d->av_context,&orig,&got_picture,&pkt);
 				if (len<=0) {
 					ms_warning("ms_AVdecoder_process: error %i.",len);
-					if ((f->ticker->time - fpu_last_requested_time)>5000 || fpu_last_requested_time==0) {
-						fpu_last_requested_time=f->ticker->time;
+					if ((f->ticker->time - d->last_error_reported_time)>5000 || d->last_error_reported_time==0) {
+						d->last_error_reported_time=f->ticker->time;
 						ms_filter_notify_no_arg(f,MS_VIDEO_DECODER_DECODING_ERRORS);
 					}
 					break;
