@@ -28,13 +28,13 @@
 #include <sys/time.h>
 #include <sys/resource.h>
 
-#include <ortp/zrtp.h>
+#include "ortp/zrtp.h"
 #include <cpu-features.h>
 
 static MSFilter *hackLastSoundReadFilter=0; // hack for Galaxy S
 
-static const float sndwrite_flush_threshold=0.050;	//ms
-static const float sndread_flush_threshold=0.050; //ms
+static const float sndwrite_flush_threshold=0.020;	//ms
+static const float sndread_flush_threshold=0.020; //ms
 static void sound_read_setup(MSFilter *f);
 
 #ifdef __cplusplus
@@ -175,15 +175,50 @@ static int set_nchannels(MSFilter *f, void *arg){
 }
 
 
+static unsigned int get_supported_rate(unsigned int prefered_rate) {
+	JNIEnv *jni_env = ms_get_jni_env();
+	jclass audio_record_class = jni_env->FindClass("android/media/AudioRecord");
+	int size = jni_env->CallStaticIntMethod(audio_record_class
+											,jni_env->GetStaticMethodID(audio_record_class,"getMinBufferSize", "(III)I")
+											,prefered_rate
+											,2/*CHANNEL_CONFIGURATION_MONO*/
+											,2/*  ENCODING_PCM_16BIT */);
 
 
+	if (size > 0) {
+		return prefered_rate;
+	} else {
+		ms_warning("Cannot configure recorder with rate [%i]",prefered_rate);
+		if (prefered_rate>48000) {
+			return get_supported_rate(48000);
+		}
+		switch (prefered_rate) {
+		case 12000:
+		case 24000: return get_supported_rate(48000);
+		case 48000: return get_supported_rate(44100);
+		case 44100: return get_supported_rate(16000);
+		case 16000: return get_supported_rate(8000);
+				default: {
+					ms_error("This Android sound card doesn't support any standard sample rate");
+					return 0;
+				}
+		}
+
+		return 0;
+	}
+
+}
+
 /***********************************read filter********************/
 static int set_read_rate(MSFilter *f, void *arg){
-	int proposed_rate = *((int*)arg);
+	unsigned int proposed_rate = *((unsigned int*)arg);
 	ms_debug("set_rate %d",proposed_rate);
 	msandroid_sound_data *d=(msandroid_sound_data*)f->data;
-	d->rate=proposed_rate;
-	return 0;
+	d->rate=get_supported_rate(proposed_rate);
+	if (d->rate == proposed_rate)
+		return 0;
+	else
+		return -1;
 }
 
 static int get_latency(MSFilter *f, void *arg){
@@ -227,6 +262,12 @@ public:
 	double av_skew;
 };
 
+static uint64_t get_wallclock_ms(void){
+	MSTimeSpec ts;
+	ms_get_cur_time(&ts);
+	return (ts.tv_sec*1000LL) + ((ts.tv_nsec+500000LL)/1000000LL);
+}
+
 static void* msandroid_read_cb(msandroid_sound_read_data* d) {
 	mblk_t *m;
 	int nread;
@@ -353,11 +394,7 @@ static void sound_read_setup(MSFilter *f){
 	}
 }
 
-static uint64_t get_wallclock_ms(void){
-	MSTimeSpec ts;
-	ms_get_cur_time(&ts);
-	return (ts.tv_sec*1000LL) + ((ts.tv_nsec+500000LL)/1000000LL);
-}
+
 
 static const double clock_coef=.01;
 
@@ -365,16 +402,21 @@ static uint64_t sound_read_time_func(msandroid_sound_read_data *d){
 	static int count;
 	uint64_t sound_time;
 	uint64_t wc=get_wallclock_ms();
+	uint64_t samplestime;
 
 	if (d->read_samples==0){
 		d->wc_offset=0;
 		return wc;
 	}
+	samplestime=(1000LL*d->read_samples)/(int64_t)d->rate;
+	if (samplestime<5000){
+		return wc;
+	}
+	if (d->wc_offset==0){
+		d->wc_offset=wc-samplestime;
+	}
 	
-	if (d->wc_offset==0)
-		d->wc_offset=wc;
-	
-	sound_time=d->wc_offset+((1000*d->read_samples)/(int64_t)d->rate);
+	sound_time=d->wc_offset+samplestime;
 	int diff=(int64_t)wc-(int64_t)sound_time;
 	d->av_skew=(d->av_skew*(1.0-clock_coef)) + ((double)diff*clock_coef);
 	count++;
@@ -565,6 +607,11 @@ static void* msandroid_write_cb(msandroid_sound_write_data* d) {
 	jbyteArray 		write_buff;
 	jmethodID 		write_id=0;
 	jmethodID play_id=0;
+	int min_size=-1;
+	int count;
+	int max_size=sndwrite_flush_threshold*(float)d->rate*(float)d->nchannels*2.0;
+	int check_point_size=3*(float)d->rate*(float)d->nchannels*2.0; /*3 seconds*/
+	int nwrites=0;
 
 	set_high_prio();
 	int buff_size = d->write_chunk_size;
@@ -595,22 +642,29 @@ static void* msandroid_write_cb(msandroid_sound_write_data* d) {
 		int bufferizer_size;
 
 		ms_mutex_lock(&d->mutex);
-		
+		min_size=-1;
+		count=0;
 		while((bufferizer_size = ms_bufferizer_get_avail(d->bufferizer)) >= d->write_chunk_size) {
-			if (bufferizer_size > sndwrite_flush_threshold*(float)d->rate*(float)d->nchannels*2.0) {
-				ms_warning("we are late [%i] bytes, flushing",bufferizer_size);
-				ms_bufferizer_flush(d->bufferizer);
+			if (min_size==-1) min_size=bufferizer_size;
+			else if (bufferizer_size<min_size) min_size=bufferizer_size;
 
-			} else {
-				ms_bufferizer_read(d->bufferizer, tmpBuff, d->write_chunk_size);
-				ms_mutex_unlock(&d->mutex);
-				jni_env->SetByteArrayRegion(write_buff,0,d->write_chunk_size,(jbyte*)tmpBuff);
-				int result = jni_env->CallIntMethod(d->audio_track,write_id,write_buff,0,d->write_chunk_size);
-				d->writtenBytes+=result;
-				if (result <= 0) {
-					ms_error("write operation has failed [%i]",result);
+			ms_bufferizer_read(d->bufferizer, tmpBuff, d->write_chunk_size);
+			ms_mutex_unlock(&d->mutex);
+			jni_env->SetByteArrayRegion(write_buff,0,d->write_chunk_size,(jbyte*)tmpBuff);
+			int result = jni_env->CallIntMethod(d->audio_track,write_id,write_buff,0,d->write_chunk_size);
+			d->writtenBytes+=result;
+			if (result <= 0) {
+				ms_error("write operation has failed [%i]",result);
+			}
+			nwrites++;
+			ms_mutex_lock(&d->mutex);
+			count+=d->write_chunk_size;
+			if (count>check_point_size){
+				if (min_size > max_size) {
+					ms_warning("we are late, flushing %i bytes",min_size);
+					ms_bufferizer_skip_bytes(d->bufferizer,min_size);
 				}
-				ms_mutex_lock(&d->mutex);
+				count=0;
 			}
 		}
 		if (d->started) {
