@@ -17,6 +17,10 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
+#if defined(HAVE_CONFIG_H)
+#include "mediastreamer-config.h"
+#endif
+
 #include "mediastreamer2/msfileplayer.h"
 #include "mediastreamer2/waveheader.h"
 #include "mediastreamer2/msticker.h"
