@@ -28,6 +28,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define INVIDEOUT_C 1
 #include "mediastreamer2/msvideoout.h"
 
+#ifdef __APPLE__
+#include <CoreFoundation/CFRunLoop.h>
+#endif
 
 struct _MSDisplay;
 
@@ -114,8 +117,6 @@ void ms_display_destroy(MSDisplay *d);
 }
 #endif
 
-#include "ffmpeg-priv.h"
-
 #define SCALE_FACTOR 4.0f
 #define SELVIEW_POS_INACTIVE -100.0
 
@@ -195,11 +196,15 @@ static void sdl_show_window(bool_t show){
 #else
 
 static void sdl_show_window(bool_t show){
+	#if !SDL_VERSION_ATLEAST(1, 3, 0)
 	ms_warning("SDL window show/hide not implemented");
+	#endif
 }
 
 static long sdl_get_native_window_id(){
+	#if !SDL_VERSION_ATLEAST(1, 3, 0)
 	ms_warning("sdl_get_native_window_id not implemented");
+	#endif
 	return 0;
 }
 
@@ -237,6 +242,7 @@ static int sdl_create_window(SdlDisplay *wd, int w, int h){
 	if (info->blit_hw_A)
 		ms_message("Alpha blits between sw to hw surfaces: accelerated");
 
+	ms_debug("Setting SDL video mode");
 	wd->sdl_screen = SDL_SetVideoMode(w,h, 0,flags);
 	if (wd->sdl_screen == NULL ) {
 		ms_warning("no hardware for video mode: %s\n",
@@ -249,27 +255,49 @@ static int sdl_create_window(SdlDisplay *wd, int w, int h){
 		SDL_WM_SetCaption("Video window", NULL);
 		once=FALSE;
 	}
+
 	wd->lay=SDL_CreateYUVOverlay(w , h ,SDL_YV12_OVERLAY,wd->sdl_screen);
 	if (wd->lay==NULL){
 		ms_warning("Couldn't create yuv overlay: %s\n",
 						SDL_GetError());
 		return -1;
 	}else{
+		ms_message("Number of planes: %i", wd->lay->planes);
+		SDL_LockYUVOverlay(wd->lay); // necessary for getting accurate plane addresses since SDL 1.3
 		ms_message("%i x %i YUV overlay created: hw_accel=%i, pitches=%i,%i,%i",wd->lay->w,wd->lay->h,wd->lay->hw_overlay,
 			wd->lay->pitches[0],wd->lay->pitches[1],wd->lay->pitches[2]);
 		ms_message("planes= %p %p %p  %i %i",wd->lay->pixels[0],wd->lay->pixels[1],wd->lay->pixels[2],
 			wd->lay->pixels[1]-wd->lay->pixels[0],wd->lay->pixels[2]-wd->lay->pixels[1]);
+		SDL_UnlockYUVOverlay(wd->lay);
 	}
+#ifdef __linux
+	/* on mac the cursor is hidden for all the desktop instead of just
+	the SDL window ! */
 	SDL_ShowCursor(0);//Hide the mouse cursor if was displayed
+#endif	
 	return 0;
 }
 
+static void free_overlay_and_surface(SdlDisplay* wd) {
+	if (wd->lay!=NULL) {
+		ms_message("Freeing overlay");
+		SDL_FreeYUVOverlay(wd->lay);
+	}
+	if (wd->sdl_screen!=NULL) {
+		ms_message("Freeing surface");
+		SDL_FreeSurface(wd->sdl_screen);
+	}
+	wd->lay=NULL;
+	wd->sdl_screen=NULL;
+}
+
 static bool_t sdl_display_init(MSDisplay *obj, MSFilter *f, MSPicture *fbuf, MSPicture *fbuf_selfview){
 	SdlDisplay *wd = (SdlDisplay*)obj->data;
 	int i;
 	if (wd==NULL){
 		char driver[128];
 		/* Initialize the SDL library */
+		ms_message("Initialize SDL video");
 		wd=(SdlDisplay*)ms_new0(SdlDisplay,1);
 		wd->filter = f;
 		obj->data=wd;
@@ -286,13 +314,9 @@ static bool_t sdl_display_init(MSDisplay *obj, MSFilter *f, MSPicture *fbuf, MSP
 		ms_mutex_lock(&wd->sdl_mutex);
 		
 	}else {
+		ms_message("Cleaning WD");
 		ms_mutex_lock(&wd->sdl_mutex);
-		if (wd->lay!=NULL)
-			SDL_FreeYUVOverlay(wd->lay);
-		if (wd->sdl_screen!=NULL)
-			SDL_FreeSurface(wd->sdl_screen);
-		wd->lay=NULL;
-		wd->sdl_screen=NULL;
+		free_overlay_and_surface(wd);
 	}
 	wd->filter = f;
 		
@@ -367,7 +391,10 @@ static void sdl_display_update(MSDisplay *obj, int new_image, int new_selfview){
 	rect.y = (wd->screen_size.height-h)/2;
 	rect.w = w;
 	rect.h = h;
-	SDL_DisplayYUVOverlay(wd->lay,&rect);
+	
+	if (SDL_DisplayYUVOverlay(wd->lay,&rect) != 0) 
+		ms_error("Error while displaying overlay");
+
 	ms_mutex_unlock(&wd->sdl_mutex);
 }
 
@@ -375,9 +402,7 @@ static int sdl_poll_event(MSDisplay *obj, MSDisplayEvent *ev){
 	SdlDisplay *wd = (SdlDisplay*)obj->data;
 	SDL_Event event;
 	if (wd->sdl_screen==NULL) return -1;
-	ms_mutex_lock(&wd->sdl_mutex);
 	if (SDL_PollEvent(&event)){
-		ms_mutex_unlock(&wd->sdl_mutex);
 		switch(event.type){
 			case SDL_VIDEORESIZE:
 				ev->evtype=MS_DISPLAY_RESIZE_EVENT;
@@ -391,27 +416,24 @@ static int sdl_poll_event(MSDisplay *obj, MSDisplayEvent *ev){
 				return 0;
 			break;
 		}
-	}else ms_mutex_unlock(&wd->sdl_mutex);
+	}
 	return -1;
 }
 
 static void sdl_display_uninit(MSDisplay *obj){
 	SdlDisplay *wd = (SdlDisplay*)obj->data;
-	SDL_Event event;
-	int i;
-	if (wd==NULL)
-		return;
-	if (wd->lay!=NULL)
-		SDL_FreeYUVOverlay(wd->lay);
-	if (wd->sdl_screen!=NULL){
-		SDL_FreeSurface(wd->sdl_screen);
-		wd->sdl_screen=NULL;
+
+	if (wd!=NULL) {
+		free_overlay_and_surface(wd);
+		ms_free(wd);
+		wd=NULL;
 	}
-	wd->lay=NULL;
-	wd->sdl_screen=NULL;
-	ms_free(wd);
+	ms_message("WD Fred");
+
 #ifdef __linux
 	/*purge the event queue before leaving*/
+	SDL_Event event;
+	int i;
 	for(i=0;SDL_PollEvent(&event) && i<100;++i){
 	}
 #endif
@@ -462,7 +484,7 @@ void ms_display_desc_set_default_window_id(MSDisplayDesc *desc, long id){
 
 typedef struct VideoOut
 {
-	AVRational ratio;
+	struct Rational {int num; int den;} ratio;
 	MSPicture fbuf;
 	MSPicture fbuf_selfview;
 	MSPicture local_pic;
@@ -474,13 +496,19 @@ typedef struct VideoOut
 	float sv_posx,sv_posy;
 	int background_color[3];
 
-	struct ms_SwsContext *sws1;
-	struct ms_SwsContext *sws2;
+	MSScalerContext *sws1;
+	MSScalerContext *sws2;
 	MSDisplay *display;
 	bool_t own_display;
 	bool_t ready;
 	bool_t autofit;
 	bool_t mirror;
+
+#ifdef __APPLE__
+	bool_t need_update;
+	CFRunLoopTimerRef timer;
+	CFRunLoopTimerContext timer_context;
+#endif
 } VideoOut;
 
 static void set_corner(VideoOut *s, int corner)
@@ -522,6 +550,7 @@ static void set_vsize(VideoOut *s, MSVideoSize *sz){
 }
 
 static void video_out_init(MSFilter  *f){
+	ms_message("video_out_init");
 	VideoOut *obj=(VideoOut*)ms_new0(VideoOut,1);
 	MSVideoSize def_size;
 	obj->ratio.num=11;
@@ -552,11 +581,11 @@ static void video_out_uninit(MSFilter *f){
 	if (obj->display!=NULL && obj->own_display)
 		ms_display_destroy(obj->display);
 	if (obj->sws1!=NULL){
-		ms_sws_freeContext(obj->sws1);
+		ms_scaler_context_free(obj->sws1);
 		obj->sws1=NULL;
 	}
 	if (obj->sws2!=NULL){
-		ms_sws_freeContext(obj->sws2);
+		ms_scaler_context_free(obj->sws2);
 		obj->sws2=NULL;
 	}
 	if (obj->local_msg!=NULL) {
@@ -581,11 +610,11 @@ static void video_out_prepare(MSFilter *f){
 		obj->display=NULL;
 	}
 	if (obj->sws1!=NULL){
-		ms_sws_freeContext(obj->sws1);
+		ms_scaler_context_free(obj->sws1);
 		obj->sws1=NULL;
 	}
 	if (obj->sws2!=NULL){
-		ms_sws_freeContext(obj->sws2);
+		 ms_scaler_context_free(obj->sws2);
 		obj->sws2=NULL;
 	}
 	if (obj->local_msg!=NULL) {
@@ -626,8 +655,64 @@ static int _video_out_handle_resizing(MSFilter *f, void *data){
 	return ret;
 }
 
+static void poll_for_resizing(MSFilter *f) {
+	int i;
+	for(i=0;i<100;++i){
+		int ret = _video_out_handle_resizing(f, NULL);
+		if (ret<0) break;
+	}
+}
+
+
+#ifdef __APPLE__
+static void apple_loop_cb(CFRunLoopTimerRef timer, void *info) {
+	MSFilter *f = (MSFilter *) info;
+	VideoOut *obj=(VideoOut*)f->data;
+	poll_for_resizing(f);
+	ms_filter_lock(f);
+	if (!obj->ready) video_out_prepare(f);
+
+	if (obj->need_update) {
+		ms_display_update(obj->display, 1, 1);
+		obj->need_update=false;
+	}
+
+	ms_filter_unlock(f);
+}
+#endif
+
+static void video_out_postprocess(MSFilter *f){
+#ifdef __APPLE__
+	VideoOut* obj = (VideoOut*) f->data;
+	CFRunLoopRemoveTimer(CFRunLoopGetCurrent(), obj->timer, kCFRunLoopCommonModes);
+	obj->timer = NULL;
+#endif
+}
+
 static void video_out_preprocess(MSFilter *f){
+#ifndef __APPLE__
 	video_out_prepare(f);
+#else
+	VideoOut* obj = (VideoOut*) f->data;
+	if (obj->timer != NULL) ms_error("Non null timer found");
+
+	CFTimeInterval interval=0.01f; // 10 milliseconds
+	obj->timer_context.version=0;
+	obj->timer_context.info=f;
+	obj->timer_context.retain=NULL;
+	obj->timer_context.release=NULL;
+	obj->timer_context.copyDescription=NULL;
+
+	obj->timer = CFRunLoopTimerCreate (NULL,
+   		CFAbsoluteTimeGetCurrent() + interval,
+   		interval,
+   		0,
+		0,
+		apple_loop_cb,
+		&(obj->timer_context)
+);
+	CFRunLoopAddTimer (CFRunLoopGetCurrent(), obj->timer, kCFRunLoopCommonModes);
+#endif
 }
 
 
@@ -636,16 +721,15 @@ static void video_out_process(MSFilter *f){
 	mblk_t *inm;
 	int update=0;
 	int update_selfview=0;
-	int i;
 
-	for(i=0;i<100;++i){
-		int ret = _video_out_handle_resizing(f, NULL);
-		if (ret<0)
-			break;
-	}
+#ifdef __APPLE__
+	ms_filter_lock(f);
+#else
+	poll_for_resizing(f);
 	ms_filter_lock(f);
 	if (!obj->ready) video_out_prepare(f);
-	if (obj->display==NULL){
+#endif
+	if (!obj->ready){
 		ms_filter_unlock(f);
 		if (f->inputs[0]!=NULL)
 			ms_queue_flush(f->inputs[0]);
@@ -665,13 +749,12 @@ static void video_out_process(MSFilter *f){
 			if (ms_yuv_buf_init_from_mblk(&src,inm)==0){
 				
 				if (obj->sws2==NULL){
-					obj->sws2=ms_sws_getContext(src.w,src.h,PIX_FMT_YUV420P,
-											 obj->fbuf_selfview.w,obj->fbuf_selfview.h,PIX_FMT_YUV420P,
-											 SWS_FAST_BILINEAR, NULL, NULL, NULL);
+					obj->sws2=ms_scaler_create_context(src.w,src.h,MS_YUV420P,
+											 obj->fbuf_selfview.w,obj->fbuf_selfview.h,MS_YUV420P,
+											 MS_SCALER_METHOD_BILINEAR);
 				}
 				ms_display_lock(obj->display);
-				if (ms_sws_scale(obj->sws2,src.planes,src.strides, 0,
-							  src.h, obj->fbuf_selfview.planes, obj->fbuf_selfview.strides)<0){
+				if (ms_scaler_process(obj->sws2,src.planes,src.strides,obj->fbuf_selfview.planes, obj->fbuf_selfview.strides)<0){
 					ms_error("Error in ms_sws_scale().");
 				}
 				if (!mblk_get_precious_flag(inm)) ms_yuv_buf_mirror(&obj->fbuf_selfview);
@@ -683,9 +766,9 @@ static void video_out_process(MSFilter *f){
 			if (ms_yuv_buf_init_from_mblk(&src,inm)==0){
 				
 				if (obj->sws2==NULL){
-					obj->sws2=ms_sws_getContext(src.w,src.h,PIX_FMT_YUV420P,
-								obj->local_pic.w,obj->local_pic.h,PIX_FMT_YUV420P,
-								SWS_FAST_BILINEAR, NULL, NULL, NULL);
+					obj->sws2=ms_scaler_create_context(src.w,src.h,MS_YUV420P,
+								obj->local_pic.w,obj->local_pic.h,MS_YUV420P,
+								MS_SCALER_METHOD_BILINEAR);
 				}
 				if (obj->local_msg==NULL){
 					obj->local_msg=ms_yuv_buf_alloc(&obj->local_pic,
@@ -693,8 +776,7 @@ static void video_out_process(MSFilter *f){
 				}
 				if (obj->local_pic.planes[0]!=NULL)
 				{
-					if (ms_sws_scale(obj->sws2,src.planes,src.strides, 0,
-						src.h, obj->local_pic.planes, obj->local_pic.strides)<0){
+					if (ms_scaler_process(obj->sws2,src.planes,src.strides,obj->local_pic.planes, obj->local_pic.strides)<0){
 						ms_error("Error in ms_sws_scale().");
 					}
 					if (!mblk_get_precious_flag(inm)) ms_yuv_buf_mirror(&obj->local_pic);
@@ -714,30 +796,36 @@ static void video_out_process(MSFilter *f){
 			newsize.width=src.w;
 			newsize.height=src.h;
 			if (obj->autofit && !ms_video_size_equal(newsize,obj->prevsize) ) {
-				MSVideoSize qvga_size;
-				qvga_size.width=MS_VIDEO_SIZE_QVGA_W;
-				qvga_size.height=MS_VIDEO_SIZE_QVGA_H;
+				MSVideoSize new_window_size;
+				static const MSVideoSize min_size=MS_VIDEO_SIZE_QVGA;
 				obj->prevsize=newsize;
 				ms_message("received size is %ix%i",newsize.width,newsize.height);
 				/*don't resize less than QVGA, it is too small*/
-				if (ms_video_size_greater_than(qvga_size,newsize)){
-					newsize.width=MS_VIDEO_SIZE_QVGA_W;
-					newsize.height=MS_VIDEO_SIZE_QVGA_H;
-				}
-				if (!ms_video_size_equal(newsize,cur)){
-					set_vsize(obj,&newsize);
+				if (min_size.width*min_size.height>newsize.width*newsize.height){
+					new_window_size.width=newsize.width*2;
+					new_window_size.height=newsize.height*2;
+				}else new_window_size=newsize;
+				
+				if (!ms_video_size_equal(new_window_size,cur)){
+					set_vsize(obj,&new_window_size);
 					ms_message("autofit: new size is %ix%i",newsize.width,newsize.height);
+					#ifndef __APPLE__
 					video_out_prepare(f);
+					#else
+					obj->ready=false;
+					ms_queue_flush(f->inputs[0]);
+					ms_filter_unlock(f);
+					return;
+					#endif
 				}
 			}
 			if (obj->sws1==NULL){
-				obj->sws1=ms_sws_getContext(src.w,src.h,PIX_FMT_YUV420P,
-				obj->fbuf.w,obj->fbuf.h,PIX_FMT_YUV420P,
-				SWS_FAST_BILINEAR, NULL, NULL, NULL);
+				obj->sws1=ms_scaler_create_context(src.w,src.h,MS_YUV420P,
+				obj->fbuf.w,obj->fbuf.h,MS_YUV420P,
+				MS_SCALER_METHOD_BILINEAR);
 			}
 			ms_display_lock(obj->display);
-			if (ms_sws_scale(obj->sws1,src.planes,src.strides, 0,
-            			src.h, obj->fbuf.planes, obj->fbuf.strides)<0){
+			if (ms_scaler_process(obj->sws1,src.planes,src.strides,obj->fbuf.planes, obj->fbuf.strides)<0){
 				ms_error("Error in ms_sws_scale().");
 			}
 			if (obj->mirror && !mblk_get_precious_flag(inm)) ms_yuv_buf_mirror(&obj->fbuf);
@@ -765,7 +853,14 @@ static void video_out_process(MSFilter *f){
 		ms_display_unlock(obj->display);
 	}
 
-	ms_display_update(obj->display, update, update_selfview);
+	if (update == 1 || update_selfview == 1) {
+		#ifdef __APPLE__
+		obj->need_update = true;
+		#else
+		ms_display_update(obj->display, update, update_selfview);
+		#endif
+	}
+
 	ms_filter_unlock(f);
 }
 
@@ -937,9 +1032,11 @@ MSFilterDesc ms_video_out_desc={
 	.init=video_out_init,
 	.preprocess=video_out_preprocess,
 	.process=video_out_process,
+	.postprocess=video_out_postprocess,
 	.uninit=video_out_uninit,
 	.methods=methods
 };
 
 
 MS_FILTER_DESC_EXPORT(ms_video_out_desc)
+
