@@ -185,6 +185,8 @@ static void choose_display_name(VideoStream *stream){
 	stream->display_name=ms_strdup("MSDrawDibDisplay");
 #elif defined(ANDROID)
 	stream->display_name=ms_strdup("MSAndroidDisplay");
+#elif __APPLE__ && !defined(__ios)
+	stream->display_name=ms_strdup("MSOSXGLDisplay");
 #elif defined (HAVE_X11_EXTENSIONS_XV_H)
 	stream->display_name=ms_strdup("MSX11Video");
 #elif defined(__ios)
@@ -583,6 +585,13 @@ void video_stream_set_rtcp_information(VideoStream *st, const char *cname, const
 	}
 }
 
+void video_stream_show_video(VideoStream *stream, bool_t show){
+	if (stream->output){
+		ms_filter_call_method(stream->output,MS_VIDEO_DISPLAY_SHOW_VIDEO,&show);
+	}
+}
+
+
 unsigned long video_stream_get_native_window_id(VideoStream *stream){
 	unsigned long id;
 	if (stream->output){
