@@ -34,8 +34,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
 #define WINSND_NBUFS 10
-#define WINSND_OUT_DELAY 0.100
-#define WINSND_OUT_NBUFS 20
+#define WINSND_OUT_DELAY 0.020
+#define WINSND_OUT_NBUFS 40
 #define WINSND_NSAMPLES 320
 #define WINSND_MINIMUMBUFFER 5
 
@@ -616,6 +616,7 @@ static void winsnd_write_process(MSFilter *f){
 			d->overrun=TRUE;
 			d->nsamples=0;
 			waveOutReset(d->outdev);
+			break;
 		}
 		d->outcurbuf++;
 	}
@@ -627,6 +628,12 @@ static int set_rate(MSFilter *f, void *arg){
 	return 0;
 }
 
+static int get_rate(MSFilter *f, void *arg){
+	WinSnd *d=(WinSnd*)f->data;
+	*((int*)arg)=d->wfx.nSamplesPerSec;
+	return 0;
+}
+
 static int set_nchannels(MSFilter *f, void *arg){
 	WinSnd *d=(WinSnd*)f->data;
 	d->wfx.nChannels=*((int*)arg);
@@ -652,6 +659,7 @@ static int winsnd_get_stat_discarded(MSFilter *f, void *arg){
 
 static MSFilterMethod winsnd_methods[]={
 	{	MS_FILTER_SET_SAMPLE_RATE	, set_rate	},
+	{	MS_FILTER_GET_SAMPLE_RATE	, get_rate	},
 	{	MS_FILTER_SET_NCHANNELS		, set_nchannels	},
 	{	MS_FILTER_GET_STAT_INPUT, winsnd_get_stat_input },
 	{	MS_FILTER_GET_STAT_OUTPUT, winsnd_get_stat_ouptut },
